@@ -100,7 +100,9 @@ class Pympress(Gtk.Application):
 
 
     def __init__(self):
-        Gtk.Application.__init__(self, application_id='io.github.pympress', flags=Gio.ApplicationFlags.HANDLES_OPEN)
+        GLib.set_application_name('pympress')
+        Gtk.Application.__init__(self, application_id='io.github.pympress',
+                                 flags=Gio.ApplicationFlags.HANDLES_OPEN | Gio.ApplicationFlags.CAN_OVERRIDE_APP_ID)
 
         self.register(None)
 
@@ -134,6 +136,7 @@ class Pympress(Gtk.Application):
             Gdk.set_allowed_backends('x11,*')
 
         logger.info(self.version_string)
+        logger.setLevel(logging.WARNING)
         Gtk.Application.do_startup(self)
 
 
