@@ -152,11 +152,17 @@ class UI(builder.Builder):
     #: A :class:`~Gtk.ShortcutsWindow` to show the shortcuts
     shortcuts_window = None
 
-    #: A :class:`Gtk.AccelGroup` to store the shortcuts
+    #: A :class:`~Gtk.AccelGroup` to store the shortcuts
     accel_group = None
-    #: A :class:`Gio.Menu` to display the recent files to open
+    #: A :class:`~Gio.Menu` to display the recent files to open
     recent_menu = None
 
+    #: A :class:`~pympress.extras.FileWatcher` object to reload modified files
+    file_watcher = None
+
+    #: `int` or `None`, may keep track of the Gtk.Application inhibit request
+    inhibit_cookie = None
+
     ##############################################################################
     #############################      UI setup      #############################
     ##############################################################################
@@ -243,6 +249,7 @@ class UI(builder.Builder):
         self.page_number = editable_label.PageNumber(self, self.config.getboolean('presenter', 'scroll_number'))
         self.timing = extras.TimingReport(self)
         self.talk_time = talk_time.TimeCounter(self, self.est_time, self.timing)
+        self.file_watcher = extras.FileWatcher()
         self.config.register_actions(self)
 
         # Get placeable widgets. NB, get the highlight one manually from the scribbler class
@@ -263,8 +270,6 @@ class UI(builder.Builder):
         # Common to both windows
         self.load_icons()
 
-        extras.FileWatcher.start_daemon()
-
         # Adjust default visibility of items
         self.prev_button.set_no_show_all(True)
         self.next_button.set_no_show_all(True)
@@ -396,7 +401,7 @@ class UI(builder.Builder):
 
         if c_full:
             self.c_win.fullscreen()
-            GLib.idle_add(lambda: util.set_screensaver(True))
+            self.set_screensaver(True)
 
         self.app.set_action_state('content-fullscreen', c_full)
         self.app.set_action_state('presenter-fullscreen', p_full)
@@ -564,11 +569,11 @@ class UI(builder.Builder):
         self.scribbler.disable_scribbling()
         self.medias.hide_all()
 
-        extras.FileWatcher.stop_daemon()
         self.doc.cleanup_media_files()
 
         if self.app.get_action_state('content-fullscreen'):
-            util.set_screensaver(False)
+            # In case we used hard-disabling
+            self.set_screensaver(disabled=False)
 
 
     def menu_about(self, *args):
@@ -618,7 +623,9 @@ class UI(builder.Builder):
 
             if not reloading and docpath:
                 Gtk.RecentManager.get_default().add_item(self.doc.get_uri())
-                extras.FileWatcher.watch_file(self.doc.get_path(), self.reload_document)
+
+            if not reloading:
+                self.file_watcher.watch_file(self.doc.get_path(), self.reload_document)
 
         except GLib.Error:
             if reloading:
@@ -626,7 +633,7 @@ class UI(builder.Builder):
 
             self.doc = document.Document.create(self, None)
             self.error_opening_file(docpath)
-            extras.FileWatcher.stop_watching()
+            self.file_watcher.stop_watching()
 
         self.current_page = self.preview_page = self.doc.goto(page)
         self.doc.goto(self.current_page)
@@ -1316,24 +1323,35 @@ class UI(builder.Builder):
         else:
             widget.fullscreen()
 
+        if gaction.get_name() == 'content-fullscreen':
+            self.set_screensaver(disabled=toggle_to)
+
         gaction.change_state(GLib.Variant.new_boolean(toggle_to))
         return True
 
 
-    def on_window_state_event(self, widget, event):
-        """ Track whether the preview window is maximized.
+    def set_screensaver(self, disabled):
+        """ Disable or re-enable the screensaver.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred
-            event (:class:`~Gtk.Event`):  the event that occurred
-
-        Returns:
-            `bool`: whether the event was consumed.
+            disabled (`bool`): `True` iff the screensaver should be disabled, otherwise enabled.
         """
-        if widget.get_name() == self.c_win.get_name():
-            fullscreen = (Gdk.WindowState.FULLSCREEN & event.new_window_state) != 0
-            util.set_screensaver(fullscreen)
-        return False
+        if not disabled:
+            if self.inhibit_cookie:
+                self.app.uninhibit(self.inhibit_cookie)
+            elif self.inhibit_cookie is not None:
+                util.hard_set_screensaver(disabled=False)
+            self.inhibit_cookie = None
+
+        else:
+            flags = (Gtk.ApplicationInhibitFlags.LOGOUT | Gtk.ApplicationInhibitFlags.SWITCH |
+                     Gtk.ApplicationInhibitFlags.SUSPEND | Gtk.ApplicationInhibitFlags.IDLE)
+
+            self.inhibit_cookie = self.app.inhibit(self.c_win, flags, _("Fullscreen Presentation running"))
+
+            if not self.inhibit_cookie:
+                logger.warning(_('Gtk.Application.inhibit failed preventing screensaver, trying hard disabling'))
+                util.hard_set_screensaver(disabled=True)
 
 
     def update_frame_position(self, widget, user_data):
